<?php

namespace Litecms\Dishes\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Dishes\Interfaces\DishRepositoryInterface;

class DishPublicController extends BaseController
{
    // use DishWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Dish\Interfaces\DishRepositoryInterface $dish
     *
     * @return type
     */
    public function __construct(DishRepositoryInterface $dish)
    {
        $this->repository = $dish;
        parent::__construct();
    }

    /**
     * Show dish's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $dishes = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$dishes::$dish.names'))
            ->view('$dishes::public.dish.index')
            ->data(compact('$dishes'))
            ->output();
    }

    /**
     * Show dish's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $dishes = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$dishes::$dish.names'))
            ->view('$dishes::public.dish.index')
            ->data(compact('$dishes'))
            ->output();
    }

    /**
     * Show dish.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $dish = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$dish->name . trans('$dishes::$dish.name'))
            ->view('$dishes::public.dish.show')
            ->data(compact('$dish'))
            ->output();
    }

}
