<?php

namespace Litecms\Dishes\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Dishes\Models\Dish;

class DishPolicy
{

    /**
     * Determine if the given user can view the dish.
     *
     * @param UserPolicy $user
     * @param Dish $dish
     *
     * @return bool
     */
    public function view(UserPolicy $user, Dish $dish)
    {
        if ($user->canDo('dishes.dish.view') && $user->isAdmin()) {
            return true;
        }

        return $dish->user_id == user_id() && $dish->user_type == user_type();
    }

    /**
     * Determine if the given user can create a dish.
     *
     * @param UserPolicy $user
     * @param Dish $dish
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('dishes.dish.create');
    }

    /**
     * Determine if the given user can update the given dish.
     *
     * @param UserPolicy $user
     * @param Dish $dish
     *
     * @return bool
     */
    public function update(UserPolicy $user, Dish $dish)
    {
        if ($user->canDo('dishes.dish.edit') && $user->isAdmin()) {
            return true;
        }

        return $dish->user_id == user_id() && $dish->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given dish.
     *
     * @param UserPolicy $user
     * @param Dish $dish
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Dish $dish)
    {
        return $dish->user_id == user_id() && $dish->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given dish.
     *
     * @param UserPolicy $user
     * @param Dish $dish
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Dish $dish)
    {
        if ($user->canDo('dishes.dish.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given dish.
     *
     * @param UserPolicy $user
     * @param Dish $dish
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Dish $dish)
    {
        if ($user->canDo('dishes.dish.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
