<?php

namespace Litecms\Dish\Providers;

use Illuminate\Support\ServiceProvider;

class DishServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'dish');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'dish');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.dish', function ($app) {
            return $this->app->make('Litecms\Dish\Dish');
        });

        // Bind Category to repository
        $this->app->bind(
            'Litecms\Dish\Interfaces\CategoryRepositoryInterface',
            \Litecms\Dish\Repositories\Eloquent\CategoryRepository::class
        );        // Bind Dish to repository
        $this->app->bind(
            'Litecms\Dish\Interfaces\DishRepositoryInterface',
            \Litecms\Dish\Repositories\Eloquent\DishRepository::class
        );

        $this->app->register(\Litecms\Dish\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Dish\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.dish'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/dish.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/dish')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/dish')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
